#!/bin/bash -e
# Filename: shared-baseimage.sh
# Author:   Matt Bearup
# Details:  Contains functions and resources used by more than one script

OSVER=$( awk '/Ubuntu/ { print $2 }' /etc/issue )
OSMAJORVER=${OSVER%%.*}

TryAptInstall() {
    for i in $(seq 3)
    do
        echo "Attempt $i to install $@"
        apt-get update > /dev/null || echo "Error running apt-get update. Attempting to install [$@] anyway"
        if apt-get install -y $@; then
            return
        else
            echo "Failed attempt [$i] to install $@. Sleep and try again..."
            sleep 30
        fi
    done
    echo "Failed to install $@. Program will now exit."
    exit 1
}

function bail {
    echo "ERROR: $@"
    exit 1
}

function bailIfFileMissing {
	file="$@"
	if [ -z "$file" ]; then
		bail "Unable to check if file is missing because no filename was specified [$file]"
	fi
	if [ ! -e "$file" ]; then
		bail "File [$file] does not exist. Exiting."
	fi
}

function bailIfFileExists {
	file="$@"
	if [ -z "$file" ]; then
		bail "Unable to check if file exists because no filename was specified [$file]"
	fi
	if [ -e "$file" ]; then
		bail "File [$file] was found when it should not exist. Exiting."
	fi
}
